<?php

/**
 * @file
 * Field module functionality for the Chessboard module.
 */

use Drupal\chessboard\PiecePlacementDataDefinition;

/**
 * Implements hook_field_info().
 */
function chessboard_field_info() {
  return array(
    'chessboard' => array(
      'label' => t('Chessboard'),
      'description' => t('An entity field containing a chessboard.'),
      'default_widget' => 'chessboard_default',
      'default_formatter' => 'chessboard_simple',
    ),
  );
}

/**
 * Implements hook_field_validate().
 */
function chessboard_field_validate($entity_type, $entity, $field, $instance, $langcode, $items, &$errors) {
  $definition = PiecePlacementDataDefinition::create()->toArray();
  $length_options = $definition['constraints']['Length'];
  $regex_options = $definition['constraints']['ChessboardRegex'];
  foreach ($items as $delta => $item) {
    if (!empty($item['piece_placement'])) {
      $length = drupal_strlen($item['piece_placement']);
      if ((NULL !== $length_options['max'] && $length > $length_options['max']) || (NULL !== $length_options['min'] && $length < $length_options['min'])) {
        $errors[$field['field_name']][$langcode][$delta][] = array(
          'error' => 'chessboard_piece_placement_length',
          'message' => t('%name: must reference %limit squares.', array('%name' => $instance['label'], '%limit' => $length_options['max'])),
        );
      }
      if (preg_match($regex_options['pattern'], $item['piece_placement']) && !$regex_options['match']) {
        $errors[$field['field_name']][$langcode][$delta][] = array(
          'error' => 'chessboard_piece_placement_allowed_piece_types',
          'message' => t('%name: only standard chess pieces allowed.', array('%name' => $instance['label'])),
        );
      }
    }
  }
}

/**
 * Implements hook_field_is_empty().
 */
function chessboard_field_is_empty($item, $field) {
  return !isset($item['piece_placement']) || $item['piece_placement'] === '';
}

/**
 * Implements hook_field_formatter_info().
 */
function chessboard_field_formatter_info() {
  return array(
    'chessboard_simple' => array(
      'label' => t('Chessboard simple'),
      'field types' => array('chessboard'),
    ),
  );
}

/**
 * Implements hook_field_formatter_view().
 */
function chessboard_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  $element = array();

  switch ($display['type']) {
    case 'chessboard_simple':
      foreach ($items as $delta => $item) {
        $element[$delta] = array(
          '#markup' => '<pre>' . check_plain(chunk_split($item['piece_placement'], 8, "\n")) . '</pre>',
        );
      }
      break;
  }
  return $element;
}

/**
 * Implements hook_field_widget_info().
 */
function chessboard_field_widget_info() {
  return array(
    'chessboard_default' => array(
      'label' => t('Chessboard'),
      'field types' => array('chessboard'),
    ),
  );
}

/**
 * Implements hook_field_widget_form().
 */
function chessboard_field_widget_form(&$form, &$form_state, $field, $instance, $langcode, $items, $delta, $element) {
  $default_value = isset($items[$delta]['piece_placement']) ? $items[$delta]['piece_placement'] : NULL;

  $widget = $element;

  switch ($instance['widget']['type']) {
    case 'chessboard_default':
      $widget += array(
        '#type' => 'textfield',
        '#default_value' => $default_value,
        '#size' => 64,
        '#maxlength' => 64,
      );
      break;
  }

  $element['piece_placement'] = $widget;
  return $element;
}
