<?php

/**
 * @file
 * Contains Drupal\chessboard_filter\Tests\ChessboardFilterTest.
 */

namespace Drupal\chessboard_filter\Tests;

use DrupalWebTestCase;

/**
 * Functional tests for the Chessboard Filter filter.
 */
class ChessboardFilterTest extends DrupalWebTestCase {
  protected $expected, $profile = 'testing';

  public static function getInfo() {

    return array(
      'name' => 'Chessboard Filter filter functionality',
      'description' => 'Filter texts and assert that the result is the same for each supported syntax.',
      'group' => 'Chessboard Renderer',
      'dependencies' => array('xautoload'),
    );
  }

  public function setUp() {
    parent::setUp(array('chessboard', 'chessboard_images', 'chessboard_filter'));

    $style = '<style scoped="scoped">' . "\n<!--/*--><![CDATA[/*><!--*/\n" . file_get_contents(drupal_get_path('module', 'chessboard_images') . '/css/chessboard_images.css') . "\n/*]]>*/-->\n" . '</style>' . "\n";
    $image_base = file_create_url(drupal_get_path('module', 'chessboard_images') . '/default');

    $this->expected['starting position'] = '<div><div class="chessboard"><div class="row"><img class="chessboard-square" src="' . $image_base . '/rdl.png" width="40" height="40" alt="r" title="" /><img class="chessboard-square" src="' . $image_base . '/ndd.png" width="40" height="40" alt="n" title="" /><img class="chessboard-square" src="' . $image_base . '/bdl.png" width="40" height="40" alt="b" title="" /><img class="chessboard-square" src="' . $image_base . '/qdd.png" width="40" height="40" alt="q" title="" /><img class="chessboard-square" src="' . $image_base . '/kdl.png" width="40" height="40" alt="k" title="" /><img class="chessboard-square" src="' . $image_base . '/bdd.png" width="40" height="40" alt="b" title="" /><img class="chessboard-square" src="' . $image_base . '/ndl.png" width="40" height="40" alt="n" title="" /><img class="chessboard-square" src="' . $image_base . '/rdd.png" width="40" height="40" alt="r" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/pdd.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdl.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdd.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdl.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdd.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdl.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdd.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdl.png" width="40" height="40" alt="p" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/pll.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pld.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pll.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pld.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pll.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pld.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pll.png" width="40" height="40" alt="P" title="" /><img class="chessboard-square" src="' . $image_base . '/pld.png" width="40" height="40" alt="P" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/rld.png" width="40" height="40" alt="R" title="" /><img class="chessboard-square" src="' . $image_base . '/nll.png" width="40" height="40" alt="N" title="" /><img class="chessboard-square" src="' . $image_base . '/bld.png" width="40" height="40" alt="B" title="" /><img class="chessboard-square" src="' . $image_base . '/qll.png" width="40" height="40" alt="Q" title="" /><img class="chessboard-square" src="' . $image_base . '/kld.png" width="40" height="40" alt="K" title="" /><img class="chessboard-square" src="' . $image_base . '/bll.png" width="40" height="40" alt="B" title="" /><img class="chessboard-square" src="' . $image_base . '/nld.png" width="40" height="40" alt="N" title="" /><img class="chessboard-square" src="' . $image_base . '/rll.png" width="40" height="40" alt="R" title="" /></div></div>' . $style . '</div>';

    $this->expected['marked squares'] = '<div><div class="chessboard"><div class="row"><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/nld.png" width="40" height="40" alt="N" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/xxl.png" width="40" height="40" alt="x" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /></div></div>' . $style . '</div>';

    $this->expected['portion'] = '<div><div class="chessboard"><div class="border-top"><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/rdl.png" width="40" height="40" alt="r" title="" /><img class="chessboard-square" src="' . $image_base . '/kdd.png" width="40" height="40" alt="k" title="" /><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/nll.png" width="40" height="40" alt="N" title="" /><img class="chessboard-square" src="' . $image_base . '/pdd.png" width="40" height="40" alt="p" title="" /><img class="chessboard-square" src="' . $image_base . '/pdl.png" width="40" height="40" alt="p" title="" /><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /></div><div class="row"><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /></div></div>' . $style . '</div>';

    $this->expected['borders'] = '<div><div class="chessboard"><div class="border-top"><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /></div><div class="row"><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /></div><div class="border-bottom"><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /></div></div>' . $style . '</div>';

    $this->expected['borders'] .= '<div><div class="chessboard"><div class="border-top"><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /></div><div class="row"><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /><img class="chessboard-square" src="' . $image_base . '/l.png" width="40" height="40" alt="-" title="" /><img class="chessboard-square" src="' . $image_base . '/d.png" width="40" height="40" alt="-" title="" /><img class="chessboard-border-v" src="' . $image_base . '/v.png" width="4" height="40" alt="" title="" /></div><div class="border-bottom"><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-h" src="' . $image_base . '/h.png" width="40" height="4" alt="" title="" /><img class="chessboard-border-c" src="' . $image_base . '/c.png" width="4" height="4" alt="" title="" /></div></div>' . $style . '</div>';

    $this->expected['archbishops'] = '<div><div class="chessboard"><div class="row"><img class="chessboard-square" src="' . $image_base . '/all.png" width="40" height="40" alt="A" title="" /><img class="chessboard-square" src="' . $image_base . '/ald.png" width="40" height="40" alt="A" title="" /><img class="chessboard-square" src="' . $image_base . '/adl.png" width="40" height="40" alt="a" title="" /><img class="chessboard-square" src="' . $image_base . '/add.png" width="40" height="40" alt="a" title="" /></div></div>' . $style . '</div>';

    $this->expected['chancellors'] = '<div><div class="chessboard"><div class="row"><img class="chessboard-square" src="' . $image_base . '/cll.png" width="40" height="40" alt="C" title="" /><img class="chessboard-square" src="' . $image_base . '/cld.png" width="40" height="40" alt="C" title="" /><img class="chessboard-square" src="' . $image_base . '/cdl.png" width="40" height="40" alt="c" title="" /><img class="chessboard-square" src="' . $image_base . '/cdd.png" width="40" height="40" alt="c" title="" /></div></div>' . $style . '</div>';

    // Add text format.
    $filtered_html_format = array(
      'format' => 'filtered_html',
      'name' => 'Filtered HTML',
      'weight' => 0,
      'filters' => array(
        // URL filter.
        'filter_url' => array(
          'weight' => 0,
          'status' => 1,
        ),
        // HTML filter.
        'filter_html' => array(
          'weight' => 1,
          'status' => 1,
        ),
        // Line break filter.
        'filter_autop' => array(
          'weight' => 2,
          'status' => 1,
        ),
        // Chessboard diagram filter.
        'chessboard_filter_diagram' => array(
          'weight' => 10,
          'status' => 1,
        ),
      ),
    );
    $filtered_html_format = (object) $filtered_html_format;
    filter_format_save($filtered_html_format);

    // Create Basic page node type.
    $this->drupalCreateContentType(array('type' => 'page', 'name' => 'Basic page'));
  }

  public function testChessboardFilterProcessField() {
    $expected = '';
    $expected .= $this->expected['starting position'];
    $expected .= $this->expected['marked squares'];
    $expected .= $this->expected['borders'];
    $expected .= $this->expected['archbishops'];
    $expected .= $this->expected['chancellors'];

    $text = '';

    // Starting position.
    $text .= '[chessboard]rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR[/chessboard]';

    // Marked squares.
    $text .= '[chessboard]8/3x1x2/2x3x1/4N3/2x3x1/3x1x2/8/8[/chessboard]';

    // Borders.
    $text .= '[chessboard](1TRBL)1[/chessboard]';
    $text .= '[chessboard](2TRBL)2[/chessboard]';

    // Archbishops.
    $text .= '[chessboard](4)AAaa[/chessboard]';

    // Chancellors.
    $text .= '[chessboard](4)CCcc[/chessboard]';

    $settings = array(
      'body' => array(LANGUAGE_NONE => array(array('value' => $text, 'format' => 'filtered_html'))),
    );
    $node = $this->drupalCreateNode($settings);
    $this->drupalGet('node/' . $node->nid);
    $this->assertRaw($expected);
  }

  public function testChessboardFilterProcessSimple() {
    $expected = '';
    $expected .= $this->expected['starting position'];
    $expected .= $this->expected['marked squares'];
    $expected .= $this->expected['portion'];

    $text = '';

    // Starting position.
    $text .= '[chessboard]
rnbqkbnr
pppppppp
--------
--------
--------
--------
PPPPPPPP
RNBQKBNR
[/chessboard]';

    // Marked squares.
    $text .= '[chessboard]
--------
---x-x--
--x---x-
----N---
--x---x-
---x-x--
--------
--------
[/chessboard]';

    // Portion of a chessboard.
    $text .= '[chessboard](d3TR)
-rk
Npp
---
[/chessboard]';

    $settings = array(
      'body' => array(LANGUAGE_NONE => array(array('value' => $text, 'format' => 'filtered_html'))),
    );
    $node = $this->drupalCreateNode($settings);

    $this->drupalGet('node/' . $node->nid);
    $this->assertRaw($expected);
  }

  public function testChessboardFilterProcessMixture() {
    $expected = $this->expected['starting position'];

    $text = '';

    // Starting position.
    $text .= '[chessboard]
rnbqkbnr
pppppppp
8/8/8/8
PPPPPPPP
RNBQKBNR
[/chessboard]';

    $settings = array(
      'body' => array(LANGUAGE_NONE => array(array('value' => $text, 'format' => 'filtered_html'))),
    );
    $node = $this->drupalCreateNode($settings);
    $this->drupalGet('node/' . $node->nid);
    $this->assertRaw($expected);
  }
}
