<?php

/**
 * @file
 * Contains Drupal\chessboard_images\PiecePlacement.
 */

namespace Drupal\chessboard_images;

use Drupal\chessboard\PiecePlacementInterface;

/**
 * Represents piece placement on a partial chessboard.
 */
class PiecePlacement implements PiecePlacementInterface {

  /**
   * The piece placement value.
   *
   * @var string
   */
  protected $value;

  /**
   * Number of files.
   *
   * @var int
   */
  protected $fileMax;

  /**
   * Constructs a piece placement object.
   *
   * @param string $value
   *   Piece placement represented as a PHP string.
   * @param int $fileMax
   *   Number of files.
   */
  public function __construct($value, $file_max) {
    $this->value = $value;
    $this->fileMax = $file_max;
  }

  /**
   * {@inheritdoc}
   */
  public function getSize() {
    return strlen($this->value);
  }

  /**
   * Implements PiecePlacementInterface::getPieceCode().
   */
  public function getPieceCode($fen_rank, $fen_file) {
    $index = $fen_rank * $this->getFileMax() + $fen_file;
    if (isset($this->value[$index])) {
      return $this->value[$index];
    }
    else {
      throw new \RuntimeException('Index invalid or out of range');
    }
  }

  public function getFileMax() {
    return $this->fileMax;
  }

}
