<?php

/**
 * @file
 * Contains Drupal\chessboard\String.
 */

namespace Drupal\chessboard;

/**
 * Represents piece placement on the chessboard.
 */
abstract class String {

  /**
   * The data definition.
   *
   * @var \Drupal\chessboard\DataDefinition
   */
  protected $definition;

  /**
   * Constructs a TypedData object given its definition.
   *
   * @param \Drupal\chessboard\DataDefinition $definition
   *   The data definition.
   */
  public function __construct(DataDefinition $definition) {
    $this->definition = $definition;
  }

  /**
   * The piece placement value.
   *
   * @var string
   */
  protected $value;

  /**
   * Gets the data definition.
   *
   * @return \Drupal\chessboard\DataDefinition
   *   The data definition object.
   */
  public function getDataDefinition() {
    return $this->definition;
  }

  /**
   * Gets the piece placement value.
   *
   * @return string
   */
  public function getValue() {
    return $this->value;
  }

  /**
   * Sets the piece placement value.
   *
   * @param string $value
   *   The piece placement value or NULL to unset the data value.
   * @param bool $notify
   *   (optional) Whether to notify the parent object of the change. Defaults to
   *   TRUE. If a property is updated from a parent object, set it to FALSE to
   *   avoid being notified again.
   *
   * @throws \InvalidArgumentException
   *   If the value input is inappropriate.
   * @throws \Drupal\Core\TypedData\ReadOnlyException
   *   If the data is read-only.
   */
  public function setValue($value, $notify = TRUE) {
    $this->value = $value;
    // Notify the parent of any changes.
    if ($notify && isset($this->parent)) {
      $this->parent->onChange($this->name);
    }
  }

}
